@@ -3,7 +3,7 @@
 export DEV='DEV'
 inotify-hookable \
     --watch-directories lib \
-    --watch-directories t/lib/TestsFor/ \
-    --watch-directories t/lib/TestMethod/ \
+    --watch-directories t \
+    --watch-directories t \
     --watch-files t/test_class_tests.t \
     --on-modify-command "prove -v t/test_class_tests.t"
